
## Usage

```py
from ayla import RankCard

rank = RankCard(
    pfp=pfp,
    background=bg,
    nickname=nick,
    level=level,
    current_xp=current,
    xp_max=max_xp,
    text_color=text_color,
    bar_color=bar_color
)

image = rank.card1()
```
<br>

## Functions

- RankCard
- ScrobbleCard (soon)